{display}
<form action="/<?php echo $this->config->item('admin_page') ?>/mconfig/index/sitemap/manage" method="post" name="module_map" id="module_map">
    <table class="compare-info">
        <thead>
            <tr>
                <td class="compare-product">{label_module}</td>
                <td class="compare-product">{label_changefreq}</td>
                <td class="compare-product">{label_priority}</td>
                <td class="compare-product">{label_base_page}</td>
            </tr>

        </thead>
        <tbody>
            {modules}
            <tr>
                <td class="name">{module_name}</td>
                <td>
                    <select name="changefreq_{module_name}">
                        {changefreq}
                    </select>
                </td>
                <td><input type="text" name="priority_{module_name}" value="{priority}" placeholder="0.5"></td>
                <td>
                    <select name="basepage_{module_name}">
                        {basepage}
                    </select>
                </td>
            </tr>
            {/modules}
        </tbody>
    </table>
</form>
<div class="form-button-box">
    {button_save}
    <img class="prepare-sitemap-loader" src="data:image/gif;base64,R0lGODlhEAAQAPIAAP///wAAAMLCwkJCQgAAAGJiYoKCgpKSkiH+GkNyZWF0ZWQgd2l0aCBhamF4bG9hZC5pbmZvACH5BAAKAAAAIf8LTkVUU0NBUEUyLjADAQAAACwAAAAAEAAQAAADMwi63P4wyklrE2MIOggZnAdOmGYJRbExwroUmcG2LmDEwnHQLVsYOd2mBzkYDAdKa+dIAAAh+QQACgABACwAAAAAEAAQAAADNAi63P5OjCEgG4QMu7DmikRxQlFUYDEZIGBMRVsaqHwctXXf7WEYB4Ag1xjihkMZsiUkKhIAIfkEAAoAAgAsAAAAABAAEAAAAzYIujIjK8pByJDMlFYvBoVjHA70GU7xSUJhmKtwHPAKzLO9HMaoKwJZ7Rf8AYPDDzKpZBqfvwQAIfkEAAoAAwAsAAAAABAAEAAAAzMIumIlK8oyhpHsnFZfhYumCYUhDAQxRIdhHBGqRoKw0R8DYlJd8z0fMDgsGo/IpHI5TAAAIfkEAAoABAAsAAAAABAAEAAAAzIIunInK0rnZBTwGPNMgQwmdsNgXGJUlIWEuR5oWUIpz8pAEAMe6TwfwyYsGo/IpFKSAAAh+QQACgAFACwAAAAAEAAQAAADMwi6IMKQORfjdOe82p4wGccc4CEuQradylesojEMBgsUc2G7sDX3lQGBMLAJibufbSlKAAAh+QQACgAGACwAAAAAEAAQAAADMgi63P7wCRHZnFVdmgHu2nFwlWCI3WGc3TSWhUFGxTAUkGCbtgENBMJAEJsxgMLWzpEAACH5BAAKAAcALAAAAAAQABAAAAMyCLrc/jDKSatlQtScKdceCAjDII7HcQ4EMTCpyrCuUBjCYRgHVtqlAiB1YhiCnlsRkAAAOwAAAAAAAAAAAA==" />
    <a href="" style="float: right;" class="btn btn-default prepare-sitemap"><?php echo $this->lang->line('Проверить'); ?></a>
</div>
<div class="additional-info">
    <?php if (!empty($error_links)) { ?>
        <h2><?php echo $this->lang->line('Список ссылок которые не будут индексироваться'); ?></h2>
        <ul class="error_links">
            <?php foreach ($error_links as $item) { ?>
                <li><a target="_blank" href="<?php echo $item; ?>"><?php echo $item; ?></a></li>
            <?php } ?>
        </ul>
    <?php } ?>
</div>